| Title: | Scrapes data from various web sources needed for PACTA |
|---|---|
| Description: | This package provides tools to scrape data from various web sources needed for PACTA. |
| Authors: | CJ Yetman [aut, cre, ctr] (ORCID: <https://orcid.org/0000-0001-5099-9500>), Jackson Hoffart [aut, ctr] (ORCID: <https://orcid.org/0000-0002-8600-5042>), Jacob Kastl [aut, ctr], Alex Axthelm [aut, ctr] (ORCID: <https://orcid.org/0000-0001-8579-8565>), RMI [cph, fnd] |
| Maintainer: | CJ Yetman <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0.9000 |
| Built: | 2026-05-24 07:19:26 UTC |
| Source: | https://github.com/rmi-pacta/pacta.data.scraping |
Get currency exchange rates for a given quarter from the IMF API
get_currency_exchange_rates(quarter, max_seconds = 60L)get_currency_exchange_rates(quarter, max_seconds = 60L)
quarter |
A single string containing the desired quarter of data in the form "2022-Q4". |
max_seconds |
A single numeric containing the max number of seconds it should wait for a response |
A dataframe containing columns currency and exchange_rate
Get the definition of MSCI regions (in terms of member countries)
get_index_regions()get_index_regions()
A dataframe containing columns equity_market, country, and
country_iso